==> devtools-ai-0.1.32b2.tar.gz: devtools-ai-0.1.32b2/README.md <==
[![sdk logo](https://dev-tools.ai/img/logo.svg)](https://dev-tools.ai/)<!-- TODO: FIXME -->

[![Python 3.7+](https://img.shields.io/badge/python-3.7%2B-blue)](https://www.python.org)
[![Apache 2.0](https://img.shields.io/badge/Apache-2.0-blue)](https://www.apache.org/licenses/LICENSE-2.0)
[![PyPI](https://img.shields.io/pypi/v/devtools-ai)](https://pypi.org/project/devtools-ai)
[![Discord](https://img.shields.io/discord/974528356253065236?&logo=discord)](https://discord.gg/2J9WEYdq5C)

DevTools SmartDriver is a Selenium & Appium SDK that makes it easy to write robust cross-device app tests backed by computer vision and artificial intelligence.

SmartDriver integrates seamelessly with your existing tests, and will act as backup if your selectors break/fail by attempting to visually (computer vision) identify elements.

SmartDriver is able to accomplish this by automatically ingesting your appium elements (using both screenshots and element names) when you run your test cases with dev-tools.ai for the first time.

The SDK is accompanied by a [web-based editor](https://smartdriver.dev-tools.ai/) which makes building visual test cases easy; you can draw boxes around your elements instead of using fragile CSS or XPath selectors.

## Install
In your terminal, run

```bash
pip install devtools-ai
```
## Tutorial
We have a detailed step-by-step tutorial which will help you get set up with the SDK: https://docs.dev-tools.ai/get-started

## Resources
* [Register/Login to your dev-tools.ai account](https://smartdriver.dev-tools.ai/login)
* [Get Started Documentation](https://docs.dev-tools.ai/)
* [Selenium Tutorial](https://docs.dev-tools.ai/category/tutorial---selenium)
* [Appium Tutorial](https://docs.dev-tools.ai/category/tutorial---appium)
* [API Docs](https://dev-tools.ai/docs/api)

==> devtools-ai-0.1.37.tar.gz: devtools-ai-0.1.37/README.md <==
[![sdk logo](https://docs.dev-tools.ai/img/logo.svg)](https://dev-tools.ai/)

[![Python 3.7+](https://img.shields.io/badge/python-3.7%2B-blue)](https://www.python.org)
[![Apache 2.0](https://img.shields.io/badge/Apache-2.0-blue)](https://www.apache.org/licenses/LICENSE-2.0)
[![PyPI](https://img.shields.io/pypi/v/devtools-ai)](https://pypi.org/project/devtools-ai)
[![Discord](https://img.shields.io/discord/974528356253065236?&logo=discord)](https://discord.gg/2J9WEYdq5C)

DevTools SmartDriver is a Selenium & Appium SDK that makes it easy to write robust cross-device app tests backed by computer vision and artificial intelligence.

SmartDriver integrates seamelessly with your existing tests, and will act as backup if your selectors break/fail by attempting to visually (computer vision) identify elements.

SmartDriver is able to accomplish this by automatically ingesting your appium elements (using both screenshots and element names) when you run your test cases with dev-tools.ai for the first time.

The SDK is accompanied by a [web-based editor](https://smartdriver.dev-tools.ai/) which makes building visual test cases easy; you can draw boxes around your elements instead of using fragile CSS or XPath selectors.

## Install
In your terminal, run

```bash
pip install devtools-ai
```
## Tutorial
We have a detailed step-by-step tutorial which will help you get set up with the SDK: https://docs.dev-tools.ai/

## Resources
* [Register/Login to your dev-tools.ai account](https://smartdriver.dev-tools.ai/login)
* [Get Started Documentation](https://docs.dev-tools.ai/)
* [Selenium Tutorial](https://docs.dev-tools.ai/selenium-basic-test-case)
* [Appium Tutorial](https://docs.dev-tools.ai/appium-basic-test-case)
* [API Docs](https://docs.dev-tools.ai/api)
